<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=is
// ** ne pas modifier le fichier **

return [

	// E
	'entree_description_site' => 'Lýsing á síðunni',

	// I
	'icone_modifier_site' => 'Breyta þessari heimasíðu',
	'info_a_valider' => '[staðfesta]',
];
